# SAMTTS

A Python port of Software Automatic Mouth Test-To-Speech program.

---

## What is SAM?

SAM is the Text-To-Speech (TTS) software SAM (Software Automatic Mouth) for the Commodore C64
published in the year 1982 by Don't Ask Software (now SoftVoice, Inc.).

This project is an unofficial Python port of SAM. It is translated by hand from the adaption to C by
[Stefan Macke](https://github.com/s-macke/SAM)
and the refactorings by 
[Vidar Hokstad](https://github.com/vidarh/SAM).

---

For details, please refer to the [Homepage](https://github.com/jacklinquan/samtts).
